summaryrefslogtreecommitdiffstats
path: root/kwin/tabbox.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-03 23:58:37 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-03 23:58:37 +0000
commite057cf9e08ab13e3f6ed139f6b0be3a06c2ec20c (patch)
treea022bd82c4c7b10cd396a463dd491d2897f70abe /kwin/tabbox.cpp
parentc3e2931a5bb4c067b0983cf23d064264d1d6b175 (diff)
downloadtdebase-e057cf9e08ab13e3f6ed139f6b0be3a06c2ec20c.tar.gz
tdebase-e057cf9e08ab13e3f6ed139f6b0be3a06c2ec20c.zip
Wean kdebase off of hacky static qt_x_*_tim variables
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1227011 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kwin/tabbox.cpp')
-rw-r--r--kwin/tabbox.cpp10
1 files changed, 4 insertions, 6 deletions
diff --git a/kwin/tabbox.cpp b/kwin/tabbox.cpp
index 6d78b4242..f5a9b9f03 100644
--- a/kwin/tabbox.cpp
+++ b/kwin/tabbox.cpp
@@ -35,8 +35,6 @@ License. See the file "COPYING" for the exact licensing terms.
// specify externals before namespace
-extern Time qt_x_time;
-
namespace KWinInternal
{
@@ -694,7 +692,7 @@ void TabBox::delayedShow()
void TabBox::handleMouseEvent( XEvent* e )
{
- XAllowEvents( qt_xdisplay(), AsyncPointer, qt_x_time );
+ XAllowEvents( qt_xdisplay(), AsyncPointer, GET_QT_X_TIME() );
if( e->type != ButtonPress )
return;
TQPoint pos( e->xbutton.x_root, e->xbutton.y_root );
@@ -852,7 +850,7 @@ void Workspace::slotWalkThroughWindows()
return;
if ( options->altTabStyle == Options::CDE || !options->focusPolicyIsReasonable())
{
//XUngrabKeyboard(qt_xdisplay(), qt_x_time); // need that because of accelerator raw mode
// CDE style raise / lower
CDEWalkThroughWindows( true );
}
@@ -1319,7 +1317,7 @@ Client* Workspace::previousStaticClient( Client* c ) const
bool Workspace::establishTabBoxGrab()
{
if( XGrabKeyboard( qt_xdisplay(), root, FALSE,
- GrabModeAsync, GrabModeAsync, qt_x_time) != GrabSuccess )
+ GrabModeAsync, GrabModeAsync, GET_QT_X_TIME()) != GrabSuccess )
return false;
// Don't try to establish a global mouse grab using XGrabPointer, as that would prevent
// using Alt+Tab while DND (#44972). However force passive grabs on all windows
@@ -1335,7 +1333,7 @@ bool Workspace::establishTabBoxGrab()
void Workspace::removeTabBoxGrab()
{
- XUngrabKeyboard(qt_xdisplay(), qt_x_time);
+ XUngrabKeyboard(qt_xdisplay(), GET_QT_X_TIME());
assert( forced_global_mouse_grab );
forced_global_mouse_grab = false;
if( active_client != NULL )
@@ -852,7 +850,7 @@ void Workspace::slotWalkThroughWindows()
if ( options->altTabStyle == Options::CDE || !options->focusPolicyIsReasonable())
{
- //XUngrabKeyboard(qt_xdisplay(), qt_x_time); // need that because of accelerator raw mode
+ //XUngrabKeyboard(qt_xdisplay(), GET_QT_X_TIME()); // need that because of accelerator raw mode
// CDE style raise / lower
CDEWalkThroughWindows( true );